@@ -4,7 +4,7 @@
 
 Result hashmap_insert(register HashMap *map, register HashItem *hashitem)
 {
-    unsigned idx;
+    size_t idx;
 
     if (map->d_n * 100 > map->d_size * 70)
         hm_expand(map);
@@ -12,7 +12,7 @@ Result hashmap_insert(register HashMap *map, register HashItem *hashitem)
     if
     (
         hm_find(&idx, map->d_map, map->d_size,
-                                hashitem_key(hashitem)) == FAILED
+                                hashitem_key(hashitem)) == UFAILED
     )
     {
         map->d_map[idx] = hashitem;
