@@ -1,19 +1,22 @@
+#include "../config.h"
+
 #include "yodl.h"
 
+/* see the note in usage.c */
+
 void warranty()
 {
-    fprintf (stderr,
-    "Yodl --  Your Own Document Languae\n"
-    "Copyright (c) 1996-2004 by"
+    fprintf (stderr, "%s%s",
+    "Yodl --  Your Own Document Language\n"
     "\n"
-    "  Karel Kubat\n"
-    "  Frank B. Brokken (f.b.brokken@rug.nl)\n"
-    "  Jan Nieuwenhuizen\n"
+    "Copyright (c) " YODL_YEARS " by Frank B. Brokken (f.b.brokken@rug.nl)\n"
+    "              1996-2004: also Karel Kubat; Jan Nieuwenhuizen\n"
     "\n"
     "    This program is free software; you can redistribute it and/or\n"
     "modify it under the terms of the GNU General Public License version 2\n"
     "as published by the Free Software Foundation.\n"
-    "\n"
+    "\n",
+
     "    This program is distributed in the hope that it will be useful,\n"
     "but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
     "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU\n"
